@@ -20,6 +20,15 @@ VQUEST_REFERENCE_DIRECTORY <- "IMGT_V-QUEST_reference_directory"
 ### Do not remove the trailing slash.
 .VQUEST_ARCHIVES_URL <- paste0(.VQUEST_DOWNLOAD_ROOT_URL, "archives/")
 
+IMGT_TERMS_OF_USE <- paste0(
+    "CONDITIONS OF USE AND LICENSE: The IMGT data is provided to the ",
+    "academic users and NPO's (Not for Profit Organization(s)) under ",
+    "the CC BY-NC-ND 4.0 license. ",
+    "See https://creativecommons.org/licenses/by-nc-nd/4.0/. ",
+    "Any other use of IMGT material, from the private sector, needs ",
+    "a financial arrangement with CNRS."
+)
+
 get_IMGT_connecttimeout <- function() getOption("IMGT_connecttimeout")
 
 
@@ -190,10 +199,10 @@ find_organism_in_IMGT_local_store <- function(organism, local_store)
         refdir <- file.path(local_store, VQUEST_REFERENCE_DIRECTORY)
         return(file.path(refdir, all_organisms[[idx]]))
     }
-    all_in_1string <- paste0("\"", all_organisms, "\"", collapse=", ")
+    in1string <- paste0("\"", all_organisms, "\"", collapse=", ")
     stop(wmsg(organism, ": organism not found in ",
               "IMGT/V-QUEST release ", basename(local_store), "."),
          "\n  ",
-         wmsg("Available organisms: ", all_in_1string, "."))
+         wmsg("Available organisms: ", in1string, "."))
 }
 
